==> client-sdk-react-1.0.0.tgz: package/src/components/Chat/CombinedChat.test.tsx <==
import { act, render, screen } from '@testing-library/react'
import { configureStore } from '@reduxjs/toolkit'
import { Provider } from 'react-redux'
import { CombinedChat } from './CombinedChat'
import { ChatInputElementProps, ChatMessageElementProps } from './models'
import React from 'react'
import { zocksStoreConfig } from '../../app/store'
import { ChatMessageAction } from '../../store/chat/models'
import { addRemoteParticipant, setLocalParticipantId } from '../../store/session/sessionSlice'
import { privateChatMessageReceived, privateChatMessageSent, savePublicChatMessage } from '../../store/chat/chatSlice'

beforeEach(() => {
  window.HTMLElement.prototype.scrollIntoView = function () {}
})

const testPublicMessages: ChatMessageAction[] = [
  {
    message: 'test public message 1',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 1,
  },
  {
    message: 'test public message 2',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 2,
  },
]

const testReceivedPrivateMessages: ChatMessageAction[] = [
  {
    message: 'test received private message 1',
    from: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    to: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 3,
  },
  {
    message: 'test received private message 2',
    from: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    to: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 4,
  },
]

const testSentPrivateMessages: ChatMessageAction[] = [
  {
    message: 'test sent private message 1',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    to: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    timestamp: 5,
  },
  {
    message: 'test sent private message 2',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    to: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    timestamp: 6,
  },
]

interface ChatRenderProps {
  receivedPrivateMessages?: ChatMessageAction[]
  sentPrivateMessages?: ChatMessageAction[]
  publicMessages?: ChatMessageAction[]
  onNewChatMessage?: () => void
  chatMessageElement?: React.FC<ChatMessageElementProps>
  chatInputElement?: React.FC<ChatInputElementProps>
}

const renderWithState = ({
  receivedPrivateMessages,
  sentPrivateMessages,
  publicMessages,
  onNewChatMessage,
  chatMessageElement,
  chatInputElement,
}: ChatRenderProps = {}) => {
  const mockChatActions = {
    sendPublicMessage: jest.fn(),
    sendPrivateMessage: jest.fn(),
    uploadAttachment: jest.fn(),
    getAttachmentLocation: jest.fn(),
  }
  const mockDismiss = jest.fn()
  const store = configureStore(zocksStoreConfig)
  store.dispatch(setLocalParticipantId('testLocalParticipantId'))
  store.dispatch(
    addRemoteParticipant({ participantId: 'testRemoteParticipantId', participantName: 'Test Remote Participant Name' })
  )
  publicMessages?.forEach((message) => store.dispatch(savePublicChatMessage(message)))
  receivedPrivateMessages?.forEach((message) => store.dispatch(privateChatMessageReceived(message)))
  sentPrivateMessages?.forEach((message) => store.dispatch(privateChatMessageSent(message)))
  const { container } = render(
    <Provider store={store}>
      <CombinedChat
        chatActions={mockChatActions}
        dismiss={mockDismiss}
        onNewChatMessage={onNewChatMessage}
        chatMessageElement={chatMessageElement}
        chatInputElement={chatInputElement}
      />
    </Provider>
  )

  return { container, store, mockChatActions, mockDismiss }
}

test('displays chat messages ordered by their timestamp', () => {
  const { container } = renderWithState({
    publicMessages: testPublicMessages,
    receivedPrivateMessages: testReceivedPrivateMessages,
    sentPrivateMessages: testSentPrivateMessages,
  })

  const chatMessages = container.querySelectorAll('.chat-message-i__message')
  expect(chatMessages.length).toBe(6)
  expect(chatMessages[0]).toHaveTextContent('test public message 1')
  expect(chatMessages[1]).toHaveTextContent('test public message 2')
  expect(chatMessages[2]).toHaveTextContent('test received private message 1')
  expect(chatMessages[3]).toHaveTextContent('test received private message 2')
  expect(chatMessages[4]).toHaveTextContent('test sent private message 1')
  expect(chatMessages[5]).toHaveTextContent('test sent private message 2')
})

test('displays messages in the same thread by omitting participant names', () => {
  renderWithState({
    publicMessages: testPublicMessages,
    receivedPrivateMessages: testReceivedPrivateMessages,
    sentPrivateMessages: testSentPrivateMessages,
  })

  expect(screen.getAllByText('Me')).toHaveLength(1)
  expect(screen.getAllByText('Test Remote Participant Name To Me')).toHaveLength(1)
  expect(screen.getAllByText('Me To Test Remote Participant Name')).toHaveLength(1)
})

test('calls the onNewChatMessage callback when a new chat message is present', () => {
  const mockNewChatMessageHandler = jest.fn()
  const { store } = renderWithState({ onNewChatMessage: mockNewChatMessageHandler })

  act(() => {
    store.dispatch(
      savePublicChatMessage({
        message: 'new public message',
        from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
        timestamp: 1,
      })
    )
  })

  expect(mockNewChatMessageHandler).toHaveBeenCalledTimes(1)
})

test('renders a custom chat input element if a custom input element is given', () => {
  const DummyChatInputElement = () => <div data-testid='dummy-chat-input' />
  renderWithState({ chatInputElement: DummyChatInputElement })

  expect(screen.getByTestId('dummy-chat-input')).toBeInTheDocument()
  expect(screen.queryByRole('textbox')).not.toBeInTheDocument()
  expect(screen.queryByRole('button', { name: 'send' })).not.toBeInTheDocument()
})

test('renders a custom chat message element if a custom message element is given', () => {
  const DummyChatMessageElement = () => <div data-testid='dummy-chat-message' />
  renderWithState({ publicMessages: testPublicMessages, chatMessageElement: DummyChatMessageElement })

  expect(screen.getAllByTestId('dummy-chat-message')).toHaveLength(2)
  expect(screen.queryByText('test public message 1')).not.toBeInTheDocument()
  expect(screen.queryByText('test public message 2')).not.toBeInTheDocument()
})

==> client-sdk-react-1.13.0.tgz: package/src/components/Chat/CombinedChat.test.tsx <==
import { render, screen } from '@testing-library/react'
import { configureStore } from '@reduxjs/toolkit'
import { Provider } from 'react-redux'
import { CombinedChat } from './CombinedChat'
import { ChatInputElementProps, ChatMessageElementProps } from './models'
import React from 'react'
import { zocksStoreConfig } from '../../app/store'
import { addRemoteParticipant, setLocalParticipantId } from '../../store/session/sessionSlice'
import {
  privateChatMessageReceived,
  privateChatMessageSent,
  publicChatMessageReceived,
} from '../../store/chat/chatSlice'
import { ChatMessageAction } from '../../store/chat/actionModels'

beforeEach(() => {
  window.HTMLElement.prototype.scrollIntoView = function () {}
})

const testPublicMessages: ChatMessageAction[] = [
  {
    message: 'test public message 1',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 1,
  },
  {
    message: 'test public message 2',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 2,
  },
]

const testReceivedPrivateMessages: ChatMessageAction[] = [
  {
    message: 'test received private message 1',
    from: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    to: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 3,
  },
  {
    message: 'test received private message 2',
    from: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    to: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    timestamp: 4,
  },
]

const testSentPrivateMessages: ChatMessageAction[] = [
  {
    message: 'test sent private message 1',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    to: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    timestamp: 5,
  },
  {
    message: 'test sent private message 2',
    from: { id: 'testLocalParticipantId', name: 'Test Local Participant Name' },
    to: { id: 'testRemoteParticipantId', name: 'Test Remote Participant Name' },
    timestamp: 6,
  },
]

interface ChatRenderProps {
  receivedPrivateMessages?: ChatMessageAction[]
  sentPrivateMessages?: ChatMessageAction[]
  publicMessages?: ChatMessageAction[]
  onNewChatMessage?: () => void
  chatMessageElement?: React.FC<ChatMessageElementProps>
  chatInputElement?: React.FC<ChatInputElementProps>
}

const renderWithState = ({
  receivedPrivateMessages,
  sentPrivateMessages,
  publicMessages,
  chatMessageElement,
  chatInputElement,
}: ChatRenderProps = {}) => {
  const mockChatActions = {
    sendPublicMessage: jest.fn(),
    sendPrivateMessage: jest.fn(),
    uploadAttachment: jest.fn(),
    getAttachmentLocation: jest.fn(),
  }
  const mockDismiss = jest.fn()
  const store = configureStore(zocksStoreConfig)
  store.dispatch(setLocalParticipantId('testLocalParticipantId'))
  store.dispatch(
    addRemoteParticipant({ participantId: 'testRemoteParticipantId', participantName: 'Test Remote Participant Name' })
  )
  publicMessages?.forEach((message) => store.dispatch(publicChatMessageReceived(message)))
  receivedPrivateMessages?.forEach((message) => store.dispatch(privateChatMessageReceived(message)))
  sentPrivateMessages?.forEach((message) => store.dispatch(privateChatMessageSent(message)))
  const { container } = render(
    <Provider store={store}>
      <CombinedChat
        chatActions={mockChatActions}
        dismiss={mockDismiss}
        chatMessageElement={chatMessageElement}
        chatInputElement={chatInputElement}
      />
    </Provider>
  )

  return { container, store, mockChatActions, mockDismiss }
}

test('displays chat messages ordered by their timestamp', () => {
  const { container } = renderWithState({
    publicMessages: testPublicMessages,
    receivedPrivateMessages: testReceivedPrivateMessages,
    sentPrivateMessages: testSentPrivateMessages,
  })

  const chatMessages = container.querySelectorAll('.chat-message-i__message')
  expect(chatMessages.length).toBe(6)
  expect(chatMessages[0]).toHaveTextContent('test public message 1')
  expect(chatMessages[1]).toHaveTextContent('test public message 2')
  expect(chatMessages[2]).toHaveTextContent('test received private message 1')
  expect(chatMessages[3]).toHaveTextContent('test received private message 2')
  expect(chatMessages[4]).toHaveTextContent('test sent private message 1')
  expect(chatMessages[5]).toHaveTextContent('test sent private message 2')
})

test('displays messages in the same thread by omitting participant names', () => {
  renderWithState({
    publicMessages: testPublicMessages,
    receivedPrivateMessages: testReceivedPrivateMessages,
    sentPrivateMessages: testSentPrivateMessages,
  })

  expect(screen.getAllByText('Me')).toHaveLength(1)
  expect(screen.getAllByText('Test Remote Participant Name To Me')).toHaveLength(1)
  expect(screen.getAllByText('Me To Test Remote Participant Name')).toHaveLength(1)
})

test('renders a custom chat input element if a custom input element is given', () => {
  const DummyChatInputElement = () => <div data-testid='dummy-chat-input' />
  renderWithState({ chatInputElement: DummyChatInputElement })

  expect(screen.getByTestId('dummy-chat-input')).toBeInTheDocument()
  expect(screen.queryByRole('textbox')).not.toBeInTheDocument()
  expect(screen.queryByRole('button', { name: 'send' })).not.toBeInTheDocument()
})

test('renders a custom chat message element if a custom message element is given', () => {
  const DummyChatMessageElement = () => <div data-testid='dummy-chat-message' />
  renderWithState({ publicMessages: testPublicMessages, chatMessageElement: DummyChatMessageElement })

  expect(screen.getAllByTestId('dummy-chat-message')).toHaveLength(2)
  expect(screen.queryByText('test public message 1')).not.toBeInTheDocument()
  expect(screen.queryByText('test public message 2')).not.toBeInTheDocument()
})
